#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include "pyro.h"

/* compute the artifical viscosity.  Here, we compute edge-centered
   approximations to the divergence of the velocity */

int artifical_viscosity(int nx, int ny, int ng, 
			double cvisc, 
			double dx, double dy,
			double **u, double **v,
			double **avisco_x, double **avisco_y) {

  int i, j;

  int imin, imax;
  int jmin, jmax;
  int qx, qy;

  double divU_x, divU_y;

  imin = ng;
  imax = ng+nx-1;

  jmin = ng;
  jmax = ng+ny-1;

  qx = 2*ng+nx;
  qy = 2*ng+ny;


  /*

   j+3/2--+---------+---------+---------+
          |         |         |         |
     j+1  +         |         |         |
          |         |         |         |
   j+1/2--+---------+---------+---------+
          |         |         |         |
        j +         X         |         |
          |         |         |         |
   j-1/2--+---------+----Y----+---------+
          |         |         |         |
      j-1 +         |         |         |
          |         |         |         |
   j-3/2--+---------+---------+---------+
          |    |    |    |    |    |    |
              i-1        i        i+1
        i-3/2     i-1/2     i+1/2     i+3/2

  
   X is the location of avisco_x[i][j]
   Y is the location of avisco_y[i][j]

  */  

  
  for (i = imin-1; i <= imax+1; i++) {
    for (j = jmin-1; j <= jmax+1; j++) {

      /* start by computing the divergence on the x-interface.  The
	 x-difference is simply the difference of the cell-centered
	 x-velocities on either side of the x-interface.  For the
	 y-difference, first average the four cells to the node on
	 each end of the edge, and then difference these to find the
	 edge centered y difference. */
      divU_x = (u[i][j] - u[i-1][j])/dx +
	0.25*(v[i][j+1] + v[i-1][j+1] - v[i][j-1] - v[i-1][j-1])/dy;

      avisco_x[i][j] = cvisc*max(-divU_x*dx, 0.0);


      /* now the y-interface value */
      divU_y = 0.25*(u[i+1][j] + u[i+1][j-1] - u[i-1][j] - u[i-1][j-1])/dx +
	(v[i][j] - v[i][j-1])/dy;

      avisco_y[i][j] = cvisc*max(-divU_y*dy, 0.0);

    }
  }

  return 1;
}

	
