/* return the conservative fluxes, given the conservative solution vector */

/*
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale

  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
*/
 
#include "interface.h"

int consFluxX(double gamma, double U[], double Flux[]) {
  
  /* compute the flux given the conserved variables -- note, the
     addition of the pressure term in the momentum flux assumes 
     Cartesian coordinates */

  double u, v, p;

  u = U[XMOM]/U[DENS];
  v = U[YMOM]/U[DENS];

  p = (U[ENER] - 0.5*U[DENS]*(u*u + v*v))*(gamma - 1.0);
  
  Flux[DENS] = U[XMOM];
  Flux[XMOM] = U[XMOM]*u + p;
  Flux[YMOM] = U[YMOM]*u;
  Flux[ENER] = (U[ENER] + p)*u;

  return 1;

}

int consFluxY(double gamma, double U[], double Flux[]) {
  
  /* compute the flux given the conserved variables -- note, the
     addition of the pressure term in the momentum flux assumes 
     Cartesian coordinates */

  double u, v, p;

  u = U[XMOM]/U[DENS];
  v = U[YMOM]/U[DENS];

  p = (U[ENER] - 0.5*U[DENS]*(u*u + v*v))*(gamma - 1.0);
  
  Flux[DENS] = U[YMOM];
  Flux[XMOM] = U[XMOM]*v ;
  Flux[YMOM] = U[YMOM]*v + p;
  Flux[ENER] = (U[ENER] + p)*v;

  return 1;

}
