; given a pyro output file and a variable name, plot the data 

pro pyro_plot, filename, variable_name, varrange=varrange, scale=scale

if n_elements(scale) EQ 0 then scale = 1

if n_elements(varrange) EQ 0 then begin
    have_varrange = 0
endif else begin
    have_varrange = 1
endelse

; get the colortable
loadct, 33

set_plot, 'X'

!p.multi      = [0,1,1]

; read in the data and find the index of the variable
pyro_read, filename, data=data, xout=x, yout=y, time=time, $
  stored_vars=vars, xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax

nx = (size(data))[1]
ny = (size(data))[2]

index_var = (where(vars EQ variable_name))[0]

if index_var EQ -1 then begin

    index_dens = (where(vars EQ "density"))[0]
    index_xmom = (where(vars EQ "x-momentum"))[0]
    index_ymom = (where(vars EQ "y-momentum"))[0]
    index_ener = (where(vars EQ "energy"))[0]

    if variable_name EQ "total velocity" then begin
        pdata = sqrt(data[*,*,index_xmom]^2 + $
                     data[*,*,index_ymom]^2)/data[*,*,index_dens]
    endif else begin
        print, "ERROR: variable not supported"
    endelse
endif else begin
    pdata = reform(data[*,*,index_var])
endelse

; all plots are full window plots
plot_pos   = [0.0, 0.0, 1.0, 1.0]

window, 0, XSIZE = scale*nx, YSIZE = scale*ny


; if we are automagically scaling, reset the data range
if NOT have_varrange then begin
    varrange = [min(pdata), max(pdata)]
endif

sdata = bytscl(pdata, min=varrange[0], max=varrange[1])


plot, [xmin, xmax], [ymin, ymax], POS = plot_pos, XSTYLE = 5, YSTYLE = 5

; convert the limits of the domain into normal coordinates
lower = convert_coord([xmin, ymin], /DATA, /TO_NORMAL)
upper = convert_coord([xmax, ymax], /DATA, /TO_NORMAL)


tvimage, sdata, position = [lower[0], lower[1], upper[0], upper[1]], $
  /OVERPLOT, /NOINTERPOLATION


    
end
