pro pyro_read, filename, $
               DATA=data, $
               STORED_VARS=vars, xout=x, yout=y, time=time, $
               XMIN=xmin, XMAX=xmax, YMIN=ymin, YMAX=ymax

;------------------------------------------------------------------------------
; open up the file for read now and read in the header information
;------------------------------------------------------------------------------

file_identifier = H5F_OPEN(filename)

;------------------------------------------------------------------------------
; grab the list of variables, and make sure that our requested
; variable (if any) exists in the dataset
;------------------------------------------------------------------------------

group = H5G_OPEN(file_identifier, "/")

; variable list
attribute = H5A_OPEN_NAME(group, "variables")

vars = reform(H5A_READ(attribute))
H5A_CLOSE, attribute


; domain extrema
attribute = H5A_OPEN_NAME(group, "xmin")
xmin = reform(H5A_READ(attribute))
H5A_CLOSE, attribute
xmin = xmin[0]

attribute = H5A_OPEN_NAME(group, "xmax")
xmax = reform(H5A_READ(attribute))
H5A_CLOSE, attribute
xmax = xmax[0]

attribute = H5A_OPEN_NAME(group, "ymin")
ymin = reform(H5A_READ(attribute))
H5A_CLOSE, attribute
ymin = ymin[0]

attribute = H5A_OPEN_NAME(group, "ymax")
ymax = reform(H5A_READ(attribute))
H5A_CLOSE, attribute
ymax = ymax[0]


attribute = H5A_OPEN_NAME(group, "time")
time = reform(H5A_READ(attribute))
H5A_CLOSE, attribute
time = time[0]

H5G_CLOSE, group


; we can also now set the number of variables
nvar = (size(vars))[1]



for i = 0, nvar-1 do begin

    dataset = H5D_OPEN(file_identifier, vars[i])
    var = H5D_READ(dataset)
    H5D_CLOSE, dataset

    ; IDL uses the opposite ordering as HDF -- correct now
    var = transpose(temporary(var))

    if (i EQ 0) then begin
        nx = (size(var))[1]
        ny = (size(var))[2]
        data = dblarr(nx,ny,nvar)
    endif

    help, var
    data[*,*,i] = var
endfor


; compute the coordinates (cell-centered)
x = (findgen(nx) + 0.5)*(xmax - xmin)/nx + xmin
y = (findgen(ny) + 0.5)*(ymax - ymin)/ny + ymin


H5F_CLOSE, file_identifier


end

