file = "sedov_0518"

gamma = 1.4

; read in the data
pyro_read, file, data=data, xout=x, yout=y, stored_vars=vars, time=time

var = "density"
index_dens = (where(var EQ vars))[0]

var = "x-momentum"
index_xmom = (where(var EQ vars))[0]

var = "y-momentum"
index_ymom = (where(var EQ vars))[0]

var = "energy"
index_ener = (where(var EQ vars))[0]

; compute the radial distance from the center
xctr = 0.5
yctr = 0.5


; bin the density
radialbin, x, y, reform(data[*,*,index_dens]), XCTR=xctr, YCTR=yctr, $
  BINCENTERS=rBinCenters, VAR=densbin

; bin the pressure
eint = (data[*,*,index_ener] - $
  0.5*(data[*,*,index_xmom]^2 + data[*,*,index_ymom]^2)/data[*,*,index_dens])
pres = eint*(gamma-1.0)

radialbin, x, y, reform(pres), XCTR=xctr, YCTR=yctr, $
  BINCENTERS=rBinCenters, VAR=presbin


; bin the velocity
vel = sqrt((data[*,*,index_xmom]^2 + data[*,*,index_ymom]^2))/data[*,*,index_dens]

radialbin, x, y, reform(vel), XCTR=xctr, YCTR=yctr, $
  BINCENTERS=rBinCenters, VAR=velbin





; now read in the analytic solution
a = readtab('sedov_cyl.txt')
help, a

r_anal = a[0,*]
v_anal = a[2,*]
rho_anal = a[3,*]
p_anal = a[4,*]

!p.multi = [0,1,3]
!p.charsize=2.5
window, xsize=600, ysize=1000

loadct, 12

; the shock position is given by r = C sqrt(t), where C is a constant
; close to 1 -- unfortunately, this constant is not tabulated in
; Sedov's book, so we take it as one here.  We are also not taking
; into account that the initial perturbation had a finite radius, r_init.
r_shock = sqrt(time)

; compute rho_2 eq. 11.11 Sedov (1959)
rho_2 = (gamma+1)/(gamma - 1)
plot, r_shock*r_anal, rho_2*rho_anal, xrange=[0.0,0.5], ytitle="density (g/cc)", /ylog, yrange=[0.01,10], thick=2
oplot, rBinCenters, densbin, psym=4, color=80

; compte p_2, eq. 11.11 Sedov (1959)
p_2 = (0.5/(gamma +1.0))/time
plot, r_shock*r_anal, p_2*p_anal, xrange=[0.0,0.5], ytitle="pressure (erg/cc)", thick=2
oplot, rBinCenters, presbin, psym=4, color=80

; compute v_2, eq. 11.11 Sedov (1959)
v_2 = (1.0/(gamma+1.0))/sqrt(time)
plot, r_shock*r_anal, v_2*v_anal, xrange=[0.0, 0.5], ytitle="velocity (cm/s)", thick=2
oplot, rBinCenters, velbin, psym=4, color=80

end


