"""
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale

  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
"""

import io_util
from numarray import *

from mesh import *
from util import runparams

def writeFile(filename, myPatch):
    """ write a single patch to the output file """

    # start by making sure that grid is a valid grid object
    if not isinstance(myPatch, patch.cellCentered):
        print "ERROR: patch invalid in io.dumpPatch()"
        print myPatch.__class__
        return -1

    # open the file
    fileId = io_util.openFile(filename)

    bcs = [myPatch.xlb, myPatch.xrb, myPatch.ylb, myPatch.yrb]
    
    # write the header
    io_util.writeHeader(fileId, myPatch.vars, myPatch.time, myPatch.dt, myPatch.nstep,
                        myPatch.nx, myPatch.ny,
                        myPatch.xmin, myPatch.xmax, myPatch.ymin, myPatch.ymax,
                        bcs)

    # write the data -- the writeData routine takes the variable name and
    # the 2-d array of data
    n = 0
    while n < myPatch.nvar:
        data = myPatch.getVarByIndex(n)
        io_util.writeData(fileId, myPatch.vars[n], \
                          data[myPatch.imin:myPatch.imax+1,
                               myPatch.jmin:myPatch.jmax+1])
        n += 1
        
    # close the file
    io_util.closeFile(fileId)

    
    

def readFile(filename):
    """ read a single patch to the output file """

    # open the file
    fileId = io_util.openForRead(filename)

    ng = 4
    
    # start by reading in the header -- use this to create a new mesh object
    time, dt = io_util.readSimulationTime(fileId)
    nstep = io_util.readSimulationStep(fileId)
    nx, ny = io_util.readGridSize(fileId)

    vars = io_util.readVarList(fileId)

    xmin, xmax, ymin, ymax = io_util.readDomainExtrema(fileId)
    [xlb, xrb, ylb, yrb] = io_util.readBCList(fileId)

    newPatch = patch.cellCentered(nx, ny, ng=ng, 
                                  xmin=xmin, xmax=xmax, ymin=ymin, ymax=ymax,
                                  xlb=xlb, xrb=xrb, ylb=ylb, yrb=yrb)

    newPatch.time = time
    newPatch.dt = dt
    newPatch.nstep = nstep
    
    n = 0
    while n < len(vars):
        newPatch.registerVar(vars[n])
        n += 1

    newPatch.init()

    # now load in the actual data
    n = 0
    while (n < len(vars)):
        newPatch.data[n,newPatch.imin:newPatch.imax+1,
                        newPatch.jmin:newPatch.jmax+1] = io_util.readData(fileId, vars[n])

        n += 1

    
    # close the file
    io_util.closeFile(fileId)

    return newPatch

    
    
