"""
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale

  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
"""


import sys
from util import runparams
from mesh import *
from numarray import *

def fillPatch(myPatch):
    """ initialize the sod problem """

    print "initializing the sod problem..."

    # make sure that we are passed a valid patch object
    if not isinstance(myPatch, patch.cellCentered):
        print "ERROR: patch invalid in io.dumpPatch()"
        print myPatch.__class__
        sys.exit()

    # maybe eventually, we make these parameters, but for now, these are
    # the standard sod parameters.
    dens_left = 1.0
    dens_right = 0.125

    u_left = 0.0
    u_right = 0.0

    p_left = 1.0
    p_right = 0.1
    

    # get the density, momenta, and energy as separate variables
    dens = myPatch.getVar("density")
    xmom = myPatch.getVar("x-momentum")
    ymom = myPatch.getVar("y-momentum")
    ener = myPatch.getVar("energy")

    # initialize the components, remember, that ener here is
    # rho*eint + 0.5*rho*v**2, where eint is the specific
    # internal energy (erg/g)
    xmin = runparams.getParam("mesh.xmin")
    xmax = runparams.getParam("mesh.xmax")

    ymin = runparams.getParam("mesh.ymin")
    ymax = runparams.getParam("mesh.ymax")

    gamma = runparams.getParam("eos.gamma")

    direction = runparams.getParam("sod.direction")
    
    xctr = 0.5*(xmin + xmax)
    yctr = 0.5*(ymin + ymax)
    
    # there is probably an easier way to do this, but for now, we
    # will just do an explicit loop.  Also, we really want to set
    # the pressue and get the internal energy from that, and then
    # compute the total energy (which is what we store).  For now
    # we will just fake this.
    if direction == "x":

        i = myPatch.imin
        while i <= myPatch.imax:

            j = myPatch.jmin
            while j <= myPatch.jmax:

                if myPatch.x[i] <= xctr:
                    dens[i,j] = dens_left
                    xmom[i,j] = dens_left*u_left
                    ymom[i,j] = 0.0
                    ener[i,j] = p_left/(gamma - 1.0) + 0.5*xmom[i,j]*u_left
                
                else:
                    dens[i,j] = dens_right
                    xmom[i,j] = dens_right*u_right
                    ymom[i,j] = 0.0
                    ener[i,j] = p_right/(gamma - 1.0) + 0.5*xmom[i,j]*u_right
                    
                j += 1
            i += 1

    else:
        i = myPatch.imin
        while i <= myPatch.imax:

            j = myPatch.jmin
            while j <= myPatch.jmax:

                if myPatch.y[j] <= yctr:
                    dens[i,j] = dens_left
                    xmom[i,j] = 0.0
                    ymom[i,j] = dens_left*u_left
                    ener[i,j] = p_left/(gamma - 1.0) + 0.5*ymom[i,j]*u_left
                
                else:
                    dens[i,j] = dens_right
                    xmom[i,j] = 0.0
                    ymom[i,j] = dens_right*u_right
                    ener[i,j] = p_right/(gamma - 1.0) + 0.5*ymom[i,j]*u_right
                    
                j += 1
            i += 1
        
    

    
                             
