/*
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale
  
  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
*/

#include <stdio.h>
#include <math.h>

#include "pyro.h" 
#include "reconstruction.h"    
 
int _flatten(int idir, int nx, int ny, int ng, 
	     double **p, double **u,
	     double smallp, double delta, double z0, double z1,
	     double **xi) {

 
  double test1, test2;
  double dp, dp2, z;
 
  int i, j;
 
  int imin, imax, jmin, jmax;
 
  imin = ng;
  imax = ng+nx-1;
  
  jmin = ng;
  jmax = ng+ny-1;
  
 
  if (idir == 1) {
 
    for (i = imin-2; i <= imax+2; i++) {
      for (j = jmin-2; j <= jmax+2; j++) {
  
        dp = fabs(p[i+1][j] - p[i-1][j]);
        dp2 = fabs(p[i+2][j] - p[i-2][j]);
        z = dp/max(dp2,smallp);
 
        test1 = u[i-1][j] - u[i+1][j];
        test2 = dp/min(p[i+1][j],p[i-1][j]);
 
        if (test1 > 0.0 && test2 > delta) {
          xi[i][j] = min(1.0, max(0.0, 1.0 - (z - z0)/(z1 - z0)));
        } else {
          xi[i][j] = 1.0;
        }
 
      }
    }
 
  } else if (idir == 2) {
 
    for (i = imin-2; i <= imax+2; i++) {
      for (j = jmin-2; j <= jmax+2; j++) {
 
        dp = fabs(p[i][j+1] - p[i][j-1]);
        dp2 = fabs(p[i][j+2] - p[i][j-2]);
        z = dp/max(dp2,smallp);
 
        test1 = u[i][j-1] - u[i][j+1];
        test2 = dp/min(p[i][j+1],p[i][j-1]);
 
        if (test1 > 0.0 && test2 > delta) {
          xi[i][j] = min(1.0, max(0.0, 1.0 - (z - z0)/(z1 - z0)));
        } else {
          xi[i][j] = 1.0;
        }
 
      }
    }
 
  } else {
    printf("ERROR: direction not supported in flattena\n");
    return -1;
  }
    
  return 1;
 
}


int _flatten_multid(int nx, int ny, int ng, 
		    double **p, double **xi_x, double **xi_y,
		    double **xi) {

 
  int sx, sy;
 
  int i, j;
 
  int imin, imax, jmin, jmax;
 
  imin = ng;
  imax = ng+nx-1;
  
  jmin = ng;
  jmax = ng+ny-1;
  
 
  for (i = imin-2; i <= imax+2; i++) {
    for (j = jmin-2; j <= jmax+2; j++) {
 
      sx = (int) sgn(p[i+1][j] - p[i-1][j]);
      sy = (int) sgn(p[i][j+1] - p[i][j-1]);
	
      xi[i][j] = min(min(xi_x[i][j], xi_x[i-sx][j]),
		    min(xi_y[i][j], xi_y[i][j-sy]));
 
    }
  }
     
  return 1;
 
}
