/*
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale
  
  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
*/

#include <stdio.h>
#include <math.h>

#include "pyro.h"
#include "reconstruction.h"
   
/* 2nd order MC limiter.  Given a[nx][ny], compute ldelta_a, the limited
   difference in the direction idir */
int _limit(int idir, int nx, int ny, int ng, double **a, double **ldelta_a) {

  int imin, imax, jmin, jmax;
  int i, j;

  double test;

  imin = ng;
  imax = ng+nx-1;
 
  jmin = ng;
  jmax = ng+ny-1;
  
  
  /* second-order limiting */
  
  if (idir == 1) {

    for (i = imin-2; i <= imax+2; i++) {
      for (j = jmin-2; j <= jmax+2; j++) {
 
	test = (a[i+1][j] - a[i][j])*(a[i][j] - a[i-1][j]);

	if (test > 0.0) {
	  ldelta_a[i][j] = min(0.5*fabs(a[i+1][j] - a[i-1][j]), 
			       min(2.0*fabs(a[i+1][j] - a[i][j]), 
				   2.0*fabs(a[i][j] - a[i-1][j]))) * 
	    sgn(a[i+1][j] - a[i-1][j]);


	} else {
	  ldelta_a[i][j] = 0.0;
	}
	
      }
    }

  } else if (idir == 2) {

    for (i = imin-2; i <= imax+2; i++) {
      for (j = jmin-2; j <= jmax+2; j++) {
 
	test = (a[i][j+1] - a[i][j])*(a[i][j] - a[i][j-1]);

	if (test > 0.0) {
	  ldelta_a[i][j] = min(0.5*fabs(a[i][j+1] - a[i][j-1]), 
			       min(2.0*fabs(a[i][j+1] - a[i][j]), 
				   2.0*fabs(a[i][j] - a[i][j-1]))) * 
	    sgn(a[i][j+1] - a[i][j-1]);


	} else {
	  ldelta_a[i][j] = 0.0;
	}
	
      }
    }

  } else {
    printf("ERROR: direction not supported in limita\n");
    return -1;
  }


  return 1;

}
