/*
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale
  
  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include "pyro.h"
#include "reconstruction.h"
   

/* 4th order MC limiter.  Given a[nx][ny], compute ldelta_a, the limited
   difference in the direction idir */
int _limit4(int idir, int nx, int ny, int ng, double **a, double **ldelta_a) {

  int imin, imax, jmin, jmax;
  int i, j;
  int qx, qy;

  double test;

  double **temp, *temp_data;

  imin = ng;
  imax = ng+nx-1;
 
  jmin = ng;
  jmax = ng+ny-1;

  qx = nx + 2*ng;
  qy = ny + 2*ng;

  
  /* fourth-order limiting */
  if (ng < 4) {
    printf("ERROR: ng must be > 4 for fourth-order limiting\n");
    return -1;
  }

  temp_data = (double *) malloc(sizeof(double)*qx*qy);
  temp = cArray_2d(temp_data, qx, qy);

  zero_2d(temp, qx, qy);
  

  if (idir == 1) {

    /* first do the normal MC limiting */
    for (i = imin-3; i <= imax+3; i++) {
      for (j = jmin-3; j <= jmax+3; j++) {

        test = (a[i+1][j] - a[i][j])*(a[i][j] - a[i-1][j]);

        if (test > 0.0) {
          temp[i][j] = min(0.5*fabs(a[i+1][j] - a[i-1][j]),
			   min(2.0*fabs(a[i+1][j] - a[i][j]),
			       2.0*fabs(a[i][j] - a[i-1][j]))) *
            sgn(a[i+1][j] - a[i-1][j]);
	  
	  
        } else {
          temp[i][j] = 0.0;
        }
	
      }
    }

    /* now the fourth order part */
    for (i = imin-2; i <= imax+2; i++) {
      for (j = jmin-2; j <= jmax+2; j++) {
 
	test = (a[i+1][j] - a[i][j])*(a[i][j] - a[i-1][j]);

	if (test > 0.0) {
	  ldelta_a[i][j] = min((2./3.)*fabs(a[i+1][j] - a[i-1][j] - 0.25*
					    (temp[i+1][j] + temp[i-1][j])),
			       min(2.0*fabs(a[i+1][j] - a[i][j]), 
				   2.0*fabs(a[i][j] - a[i-1][j])))*
	    sgn(a[i+1][j] - a[i-1][j]);

	} else {
	  ldelta_a[i][j] = 0.0;
	}
	
      }
    }

  } else if (idir == 2) {

    /* first do the normal MC limiting */
    for (i = imin-3; i <= imax+3; i++) {
      for (j = jmin-3; j <= jmax+3; j++) {

        test = (a[i][j+1] - a[i][j])*(a[i][j] - a[i][j-1]);

        if (test > 0.0) {
          temp[i][j] = min(0.5*fabs(a[i][j+1] - a[i][j-1]),
			   min(2.0*fabs(a[i][j+1] - a[i][j]),
			       2.0*fabs(a[i][j] - a[i][j-1]))) *
            sgn(a[i][j+1] - a[i][j-1]);

	  
        } else {
          temp[i][j] = 0.0;
        }

      }
    }

    /* now the fourth order part */
    for (i = imin-2; i <= imax+2; i++) {
      for (j = jmin-2; j <= jmax+2; j++) {
 
	test = (a[i][j+1] - a[i][j])*(a[i][j] - a[i][j-1]);

	if (test > 0.0) {
	  ldelta_a[i][j] = min((2./3.)*fabs(a[i][j+1] - a[i][j-1] - 0.25*
					    (temp[i][j+1] + temp[i][j-1])),
			       min(2.0*fabs(a[i][j+1] - a[i][j]), 
				   2.0*fabs(a[i][j] - a[i][j-1])))*
	    sgn(a[i][j+1] - a[i][j-1]);

	} else {
	  ldelta_a[i][j] = 0.0;
	}
	
      }
    }

  } else {
    printf("ERROR: direction not supported in limita\n");
    return -1;
  }


  free(temp_data);
  free_2d(temp);

  return 1;

}
