# a setup script for pyro:
#
# python setup.py install --home=.
#
# This installs python locally.  The PYTHONPATH environment variable will
# need to be set for this to properly function.
#

from distutils.core import setup, Extension
import os

extra_compile_args = ["-Wall", "-ansi"]

# the compressible fluxes
print " "
print "<<< starting the compressible fluxes build >>>"
print " "

setup(name="compressible_fluxes", version="1.0",
      ext_modules=[Extension("compressible_fluxes",
                             ["compressible/compressible_wrappers.c",
                              "compressible/unsplitFluxes.c",
                              "compressible/splitFluxes.c",
                              "compressible/interfacestates.c",
                              "compressible/HLLC.c",
                              "compressible/consFlux.c",
                              "compressible/artifical_viscosity.c",
                              "util/arraylib.c",
                              "util/arraylib_wrappers.c",
                              "util/misc.c",
                              "reconstruction/limit4.c",
                              "reconstruction/flatten.c"],
                             include_dirs = [".",
                                             "compressible/",
                                             "util/",
                                             "reconstruction/"],
                             extra_compile_args = extra_compile_args
                             )
                   ]
      )


# the reconstruction routines
print " "
print "<<< starting the reconstruction routines build >>>"
print " "

setup(name="reconstructionlib", version="1.0",
      ext_modules=[Extension("reconstructionlib",
                             ["reconstruction/reconstruction_wrappers.c",
                              "reconstruction/flatten.c",
                              "reconstruction/limit.c",
                              "reconstruction/limit4.c",
                              "util/arraylib.c",
                              "util/arraylib_wrappers.c",
                              "util/misc.c"],
                             include_dirs = [".", "reconstruction/", "util/"],
                             extra_compile_args = extra_compile_args
                             )
                   ]
      )


# I/O
print " "
print "<<< starting the I/O build >>>"
print " "

# set the version number -- this is a bit hackish, but works, and keeps
# all references to the version of pyro sycronized based on the VERSION
# file.
print "*** setting the version number in the io header routine ***"
os.system("cat io/io_util.c | sed -e s/@VERSION@/`cat VERSION`/g > io/io_util_build.c")


setup(name="io_util", version="1.0",
      ext_modules=[Extension("io_util",
                             ["io/io_util_build.c"],
                             libraries=["hdf5", "sz"],
                             library_dirs = ["/opt/5-1.6.4-linux-gcc/lib",
                                             "/opt/szip2.0-linux-gcc3.2.3-enc/lib/"],
                             include_dirs = [".", "io/",
                                             "/opt/5-1.6.4-linux-gcc/include/",
                                             "/opt/szip2.0-linux-gcc3.2.3-enc/include/"],
                             extra_compile_args = extra_compile_args
                             )
                   ]
      )

