#!/bin/tcsh

rm -rf lib/python/
rm -rf build/

# setup the output file
set date_str = `date "+%Y-%m-%d"`
set outfile = test-${date_str}.out

# remove the old version of the output file
rm -f ${outfile}

echo "Storing output in" ${outfile}

# make sure that we have the libraries built
python setup.py install --home=. >>& $outfile

# setup the environment
setenv PYTHONPATH `pwd`/lib/python/


# test each problem separately
echo " " >> ${outfile}
echo "starting compressible quadrant inputs.q.unsplit" >> ${outfile}

./pyro.py -t test/quad_unsplit_0148 compressible quadrant test/inputs.q.unsplit >>& ${outfile}


echo " " >> ${outfile}
echo "starting compressible quadrant inputs.q.split" >> ${outfile}

./pyro.py -t test/quad_split_0151 compressible quadrant test/inputs.q.split >>& ${outfile}


echo " " >> ${outfile}
echo "starting advection smooth inputs.smooth.unsplit" >> ${outfile}

./pyro.py -t test/smooth_unsplit_test_0081 advection smooth test/inputs.smooth.unsplit >>& ${outfile}


echo " " >> ${outfile}
echo "starting advection smooth inputs.smooth.split" >> ${outfile}

./pyro.py -t test/smooth_split_test_0081 advection smooth test/inputs.smooth.split >>& ${outfile}


echo " " >> ${outfile}
echo "starting the mesh tests" >> ${outfile}
./mesh_test.py >>& ${outfile}


echo " " >> ${outfile}
echo "starting the multigrid tests" >> ${outfile}
./mg_test.py >>& ${outfile}





 
