/*
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale
    
  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
*/

/* 
   arraylib.c contains useful functions for allocating,
   freeing, and zeroing contiguous multidimensional 
   arrays in C routines.  There is nothing python
   specific in here
*/
 
#include <stdio.h>
#include <stdlib.h>
  
#include "pyro.h"

double **cArray_2d(double *data, int qx, int qy) {

  int i;
  double **A;

  if (data == NULL) return NULL;

  A = (double **) malloc(sizeof(double *)*qx);
  if (A == NULL) {
    return NULL;
  }

  for (i = 0; i < qx; i++) {
    A[i] = data + i*qy;
  }

  return A;
}


void zero_2d(double **A, int qx, int qy) {

  int i, j;

  for (i = 0; i < qx; i++) {
    for (j = 0; j < qy; j++) {
      A[i][j] = 0.0;
    }
  }

}


double ***cArray_3d(double *data, int qx, int qy, int qz) {

  int i, j;
  double ***A;

  if (data == NULL) return NULL;

  A = (double ***) malloc(sizeof(double **)*qx);
  if (A == NULL) {
    return NULL;
  }

  for (i = 0; i < qx; i++) {
    A[i] = (double **) malloc(sizeof(double *)*qy);

    for (j = 0; j < qy; j++) {
      A[i][j] = data + i*qy*qz + j*qz;
    }
  }

  return A;
}


void zero_3d(double ***A, int qx, int qy, int qz) {

  int i, j, k;

  for (i = 0; i < qx; i++) {
    for (j = 0; j < qy; j++) {
      for (k = 0; k < qz; k++) {
        A[i][j][k] = 0.0;
      }
    }
  }

}


void free_2d(double **A) { free (A); }


void free_3d(double ***A, int qx) {
  int i;

  for (i = 0; i < qx; i++) {
    free(A[i]);
  }
  free(A);
}
