/*
  ---------------------------------------------------------------------
  Copyright (C) 2003, 2004  Michael Zingale
    
  This software is distributed under the terms of the GNU General
  Public License, version 2.  See COPYING for details.  It is covered
  by no warantee whatsoever, explicit or implied.
  ---------------------------------------------------------------------
*/

/* 
   arraylib_wrappers.c contains useful functions for interfacing
   with python numarray array objects.
*/

#include <stdio.h>
#include <stdlib.h>
  
#include "Python.h"
#include "numarray/numarray.h"
#include "numarray/libnumarray.h"

#include "pyro.h" 
#include "pyroarray.h"

int checkDims_2d(PyArrayObject *pA, int qx, int qy) {

  if (!pA || pA->nd != 2 || 
      pA->dimensions[0] != qx || pA->dimensions[1] != qy) {
    return -1;
  } else {
    return 1;
  }
}


int checkDims_3d(PyArrayObject *pA, int qx, int qy, int qz) {

  if (!pA || pA->nd != 3 || 
      pA->dimensions[0] != qx || 
      pA->dimensions[1] != qy || 
      pA->dimensions[2] != qz) {
    return -1;
  } else {
    return 1;
  }
}


void py2C_init(void) {
  import_libnumarray();
}


double **py2C_create2d(PyObject *oA, int qx, int qy, PyArrayObject **pA) {

  double **A;

  *pA = (PyArrayObject *) NA_InputArray(oA, tFloat64, NUM_C_ARRAY);

  if (!checkDims_2d(*pA, qx, qy)) {
    return NULL;
  }

  A = cArray_2d((double *) NA_OFFSETDATA((*pA)), qx, qy);

  return A;
}


void py2C_free2d(double **A, int qx, int qy, PyArrayObject *pA) {
  free_2d(A);
  Py_XDECREF(pA);
}


double ***py2C_create3d(PyObject *oA, int qx, int qy, int qz, PyArrayObject **pA) {

  double ***A;

  *pA = (PyArrayObject *) NA_InputArray(oA, tFloat64, NUM_C_ARRAY);

  if (!checkDims_3d(*pA, qx, qy, qz)) {
    return NULL;
  }

  A = cArray_3d((double *) NA_OFFSETDATA((*pA)), qx, qy, qz);

  return A;
}


void py2C_free3d(double ***A, int qx, int qy, int qz, PyArrayObject *pA) {
  free_3d(A, qx);
  Py_XDECREF(pA);
}

  
